==> phpgroupware-jp-0.9.16.003-pre1.tar.bz2: phpgroupware/admin/setup/setup.inc.php <==
<?php
	/**************************************************************************\
	* phpGroupWare - Chora                                                     *
	* http://www.phpgroupware.org                                              *
	* --------------------------------------------                             *
	*  This program is free software; you can redistribute it and/or modify it *
	*  under the terms of the GNU General Public License as published by the   *
	*  Free Software Foundation; either version 2 of the License, or (at your  *
	*  option) any later version.                                              *
	\**************************************************************************/
	/* $Id: setup.inc.php,v 1.5.8.1 2004/09/26 08:10:34 kazuyan Exp $ */

	$setup_info['admin']['name']      = 'admin';
	$setup_info['admin']['title']     = lang('Administration');
	$setup_info['admin']['version']   = '0.9.16.000';
	$setup_info['admin']['app_order'] = 1;
	$setup_info['admin']['tables']    = '';
	$setup_info['admin']['enable']    = 1;

	$setup_info['admin']['author']    = 'phpGW Core';
	$setup_info['admin']['license']   = 'GPL';
	$setup_info['admin']['description'] = 
		'phpGroupWare administration application';
	$setup_info['admin']['maintainer'] = 'phpGroupWare Coordination Team';
	$setup_info['admin']['maintainer_email'] = 'ceb@phpgroupware.org<br>jengo@phpgroupware.org<br>seek3r@phpgroupware.org<br>skeeter@phpgroupware.org';

	/* The hooks this app includes, needed for hooks registration */
	$setup_info['admin']['hooks'] = array(
		'acl_manager',
		'add_def_pref',
		'admin',
		'after_navbar',
		'config',
		'deleteaccount',
		'manual',
		'view_user' => 'admin.uiaccounts.edit_view_user_hook',
		'edit_user' => 'admin.uiaccounts.edit_view_user_hook',
		'sidebox_menu'
	);

	/* Dependacies for this app to work */
	$setup_info['admin']['depends'][] = array(
		 'appname' => 'phpgwapi',
		 'versions' => Array('0.9.16')
	);
?>

==> phpgroupware-jp-0.9.16.012-pre1.tar.bz2: phpgroupware/admin/setup/setup.inc.php <==
<?php
	/**************************************************************************\
	* phpGroupWare - Chora                                                     *
	* http://www.phpgroupware.org                                              *
	* --------------------------------------------                             *
	*  This program is free software; you can redistribute it and/or modify it *
	*  under the terms of the GNU General Public License as published by the   *
	*  Free Software Foundation; either version 2 of the License, or (at your  *
	*  option) any later version.                                              *
	\**************************************************************************/
	/* $Id: setup.inc.php,v 1.6.18.1 2007/09/14 01:58:16 kazuyan Exp $ */

	$setup_info['admin']['name']      = 'admin';
	$setup_info['admin']['title']     = lang('Administration');
	$setup_info['admin']['version']   = '0.9.16.000';
	$setup_info['admin']['app_order'] = 1;
	$setup_info['admin']['tables']    = '';
	$setup_info['admin']['enable']    = 1;

	$setup_info['admin']['author']    = 'phpGW Core';
	$setup_info['admin']['license']   = 'GPL';
	$setup_info['admin']['description'] = 
		'phpGroupWare administration application';
	$setup_info['admin']['maintainer'] = 'phpGroupWare Coordination Team';
	$setup_info['admin']['maintainer_email'] = 'ceb@phpgroupware.org<br />jengo@phpgroupware.org<br />seek3r@phpgroupware.org<br />skeeter@phpgroupware.org';

	/* The hooks this app includes, needed for hooks registration */
	$setup_info['admin']['hooks'] = array(
		'acl_manager',
		'add_def_pref',
		'admin',
		'after_navbar',
		'config',
		'deleteaccount',
		'manual',
		'view_user' => 'admin.uiaccounts.edit_view_user_hook',
		'edit_user' => 'admin.uiaccounts.edit_view_user_hook',
		'sidebox_menu'
	);

	/* Dependacies for this app to work */
	$setup_info['admin']['depends'][] = array(
		 'appname' => 'phpgwapi',
		 'versions' => Array('0.9.16')
	);
?>
